fn username_subaddress(rng: impl Rng, type: AppendType, email: String) -> StringExpand description
Generate a username using a plus addressed email address
The format is <username>+<random-or-website>@<domain>
fn username_subaddress(rng: impl Rng, type: AppendType, email: String) -> StringGenerate a username using a plus addressed email address
The format is <username>+<random-or-website>@<domain>